@@ -2,7 +2,7 @@ package Net::AMQP::RabbitMQ;
 use strict;
 use warnings;
 
-our $VERSION = '2.200000';
+our $VERSION = '2.200001';
 
 use XSLoader;
 XSLoader::load "Net::AMQP::RabbitMQ", $VERSION;
@@ -20,6 +20,7 @@ Net::AMQP::RabbitMQ - interact with RabbitMQ over AMQP using librabbitmq
   my $mq = Net::AMQP::RabbitMQ->new();
   $mq->connect("localhost", { user => "guest", password => "guest" });
   $mq->channel_open(1);
+  $mq->queue_declare(1, "queuename");
   $mq->publish(1, "queuename", "Hi there!");
   my $gotten = $mq->get(1, "queuename");
   print $gotten->{body} . "\n";
@@ -32,7 +33,7 @@ that allows connecting, declaring exchanges and queues, binding and unbinding
 queues, publishing, consuming and receiving events.
 
 Error handling in this module is primarily achieve by C<Perl_croak> (die). You
-should be making good use of eval around these methods to ensure that you
+should be making good use of C<eval> around these methods to ensure that you
 appropriately catch the errors.
 
 =head1 METHODS
@@ -48,6 +49,8 @@ Creates a new Net::AMQP::RabbitMQ object.
 
 =head2 connect( $hostname, $options )
 
+Connect to RabbitMQ server.
+
 C<$hostname> is the host to which a connection will be attempted.
 
 C<$options> is an optional hash respecting the following keys:
@@ -81,15 +84,15 @@ will exit with error code 141
 
 =head2 disconnect()
 
-Causes the connection to RabbitMQ to be torn down.
+Disconnect from the RabbitMQ server.
 
 =head2 get_server_properties()
 
-Get a hashref of server properties (these may vary, you should C<Data::Dumper> to inspect). They will be provided by the RabbitMQ server to which you are connected.
+Get a reference to hash (hashref) of server properties.  These may vary, you should use C<Data::Dumper> to inspect.  Properties will be provided for the RabbitMQ server to which you are connected.
 
 =head2 get_client_properties()
 
-Get a hashref of server properties (these may vary, you should C<Data::Dumper> to inspect).
+Get a reference to hash (hashref) of client properties.  These may vary, you should use C<Data::Dumper> to inspect.
 
 =head2 is_connected()
 
@@ -97,10 +100,14 @@ Returns true if a valid socket connection appears to exist, false otherwise.
 
 =head2 channel_open($channel)
 
+Open an AMQP channel on the connection.
+
 C<$channel> is a positive integer describing the channel you which to open.
 
 =head2 channel_close($channel)
 
+Close the specified channel.
+
 C<$channel> is a positive integer describing the channel you which to close.
 
 =head2 get_channel_max()
@@ -109,6 +116,10 @@ Returns the maximum allowed channel number.
 
 =head2 exchange_declare($channel, $exchange, $options, $arguments)
 
+Declare an AMQP exchange on the RabbitMQ server unless it already exists.  Bad
+things will happen if the exchange name already exists and different parameters
+are provided.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$exchange> is the name of the exchange to be instantiated.
@@ -133,6 +144,8 @@ C<$arguments> is an optional hash of additional arguments to the RabbitMQ server
 
 =head2 exchange_delete($channel, $exchange, $options)
 
+Delete a AMQP exchange on the RabbitMQ server.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$exchange> is the name of the exchange to be deleted.
@@ -145,6 +158,8 @@ C<$options> is an optional hash respecting the following keys:
 
 =head2 exchange_bind($channel, $destination, $source, $routing_key, $arguments)
 
+Bind a source exchange to a destination exchange with a given routing key and/or parameters.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$destination> is a previously declared exchange, C<$source> is
@@ -158,6 +173,8 @@ messages with the supplied header values.
 
 =head2 exchange_unbind($channel, $destination, $source, $routing_key, $arguments)
 
+Remove a binding between source and destination exchanges.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$destination> is a previously declared exchange, C<$source> is
@@ -171,6 +188,16 @@ messages with the supplied header values.
 
 =head2 queue_declare($channel, $queuename, $options, $arguments)
 
+Declare an AMQP queue on the RabbitMQ server.
+
+In scalar context, this method returns the queuename declared
+(important for retrieving the auto-generated queuename in the
+event that one was requested).
+
+In array context, this method returns three items: queuename,
+the number of message waiting on the queue, and the number
+of consumers bound to the queue.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$queuename> is the name of the queuename to be instantiated.  If
@@ -192,16 +219,10 @@ C<$arguments> is an optional hash which will be passed to the server
 when the queue is created.  This can be used for creating mirrored
 queues by using the x-ha-policy header.
 
-In scalar context, this method returns the queuename declared
-(important for retrieving the autogenerated queuename in the
-event that one was requested).
-
-In array context, this method returns three items: queuename,
-the number of message waiting on the queue, and the number
-of consumers bound to the queue.
-
 =head2 queue_bind($channel, $queuename, $exchange, $routing_key, $arguments)
 
+Bind the specified queue to the specified exchange with a routing key.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$queuename> is a previously declared queue, C<$exchange> is a
@@ -214,15 +235,15 @@ messages with the supplied header values.
 
 =head2 queue_unbind($channel, $queuename, $exchange, $routing_key, $arguments)
 
+Remove a binding between a queue and an exchange.  If this fails, you must reopen the channel.
+
 This is like the C<queue_bind> with respect to arguments.  This command unbinds
 the queue from the exchange.  The C<$routing_key> and C<$arguments> must match
 the values supplied when the binding was created.
 
-If this fails, you must reopen the channel
-
 =head2 queue_delete($channel, $queuename, $options)
 
-Deletes the queue
+Delete a specified queue.  If this fails, you must reopen the channel.
 
 C<$options> is an optional hash respecting the following keys:
 
@@ -231,10 +252,10 @@ C<$options> is an optional hash respecting the following keys:
        if_empty     => $boolean,     #default 1
      }
 
-If this fails, you must reopen the channel
-
 =head2 publish($channel, $routing_key, $body, $options, $props)
 
+Publish a message to an exchange.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$routing_key> is the name of the routing key for this message.
@@ -275,6 +296,11 @@ C<$props> is an optional hash (the AMQP 'props') respecting the following keys:
 
 =head2 consume($channel, $queuename, $options)
 
+Put the channel into consume mode.
+
+The C<consumer_tag> is returned.  This command does B<not> return AMQP
+messages, for that the C<recv> method should be used.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$queuename> is the name of the queue from which we'd like to consume.
@@ -288,20 +314,11 @@ C<$options> is an optional hash respecting the following keys:
        exclusive => $boolean,   #default 0
      }
 
-
-The consumer_tag is returned.  This command does B<not> return AMQP
-frames, it simply notifies RabbitMQ that messages for this queue should
-be delivered down the specified channel.
-
 =head2 recv($timeout)
 
-C<$timeout> is a positive integer, specifying the number of milliseconds to
-wait for a message. If you do not provide a timeout (or set it to 0), then
-this call will block until it receives a message. If you set it to -1 it will
-return immediately (waiting 0 ms).
+Receive AMQP messages.
 
-This command receives and reconstructs AMQP frames and returns a hash
-containing the following information:
+This method returns a reference to a hash (hashref) containing the following information:
 
      {
        body => 'Magic Transient Payload', # the reconstructed body
@@ -313,7 +330,7 @@ containing the following information:
        props => $props,                   # hashref sent in
      }
 
-C<$props> is the hash sent by publish()  respecting the following keys:
+C<$props> is the hash sent by publish() respecting the following keys:
 
      {
        content_type => $string,
@@ -330,25 +347,34 @@ C<$props> is the hash sent by publish()  respecting the following keys:
        timestamp => $integer,
      }
 
-If you provide a timeout, then the C<recv()> method returns C<undef> if the
+C<$timeout> is a positive integer, specifying the number of milliseconds to
+wait for a message. If you do not provide a timeout (or set it to 0), then
+this call will block until it receives a message. If you set it to -1 it will
+return immediately (waiting 0 ms).
+
+If you provide a timeout, then the C<recv> method returns C<undef> if the
 timeout expires before a message is received from the server.
 
 =head2 cancel($channel, $consumer_tag)
 
+Take the channel out of consume mode previously enabled with C<consume>.
+
+This method returns true or false indicating whether we got the expected
+"cancel-ok" response from the server.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$consumer_tag> is a tag previously passed to C<consume()> or one that was
 generated automatically as a result of calling C<consume()> without an
 explicit tag.
 
-This method returns true or false indicating whether we got the expected
-"cancel-ok" response from the server.
-
 =head2 get($channel, $queuename, $options)
 
-This command runs an amqp_basic_get which returns undef immediately
-if no messages are available on the queue and returns a hash as follows
-if a message is available:
+Get a message from the specified queue (via C<amqp_basic_get()>).
+
+The method returns C<undef> immediately if no messages are available
+on the queue.  If a message is available a reference to a hash (hashref) is
+returned with the following contents:
 
     {
       body => 'Magic Transient Payload', # the reconstructed body
@@ -405,48 +431,56 @@ C<$options> is an optional hash respecting the following keys:
 
 =head2 ack($channel, $delivery_tag, $multiple = 0)
 
+Acknowledge a message.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
-C<$delivery_tag> the delivery tag seen from a returned frame from the
+C<$delivery_tag> the delivery tag seen from a returned message from the
 C<recv> method.
 
 C<$multiple> specifies if multiple are to be acknowledged at once.
 
 =head2 purge($channel, $queuename)
 
+Purge all messages from the specified queue.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$queuename> is the queue to be purged.
 
 =head2 reject($channel, $delivery_tag, $requeue = 0)
 
+Reject a message with the specified delivery tag.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
-C<$delivery_tag> the delivery tag seen from a returned frame from the
+C<$delivery_tag> the delivery tag seen from a returned message from the
 C<recv> method.
 
 C<$requeue> specifies if the message should be requeued.
 
 =head2 tx_select($channel)
 
-C<$channel> is a channel that has been opened with C<channel_open>.
-
 Start a server-side (tx) transaction over $channel.
 
+C<$channel> is a channel that has been opened with C<channel_open>.
+
 =head2 tx_commit($channel)
 
-C<$channel> is a channel that has been opened with C<channel_open>.
-
 Commit a server-side (tx) transaction over $channel.
 
+C<$channel> is a channel that has been opened with C<channel_open>.
+
 =head2 tx_rollback($channel)
 
-C<$channel> is a channel that has been opened with C<channel_open>.
-
 Rollback a server-side (tx) transaction over $channel.
 
+C<$channel> is a channel that has been opened with C<channel_open>.
+
 =head2 basic_qos($channel, $options)
 
+Set quality of service flags on the current $channel.
+
 C<$channel> is a channel that has been opened with C<channel_open>.
 
 C<$options> is an optional hash respecting the following keys:
@@ -457,11 +491,9 @@ C<$options> is an optional hash respecting the following keys:
        global         => $bool, #default 0
      }
 
-Set quality of service flags on the current $channel.
-
 =head2 heartbeat()
 
-Send a heartbeat frame.  If you've connected with a heartbeat parameter,
+Send a heartbeat.  If you've connected with a heartbeat parameter,
 you must send a heartbeat periodically matching connection parameter or
 the server may snip the connection.
 
@@ -479,6 +511,52 @@ the connection has been closed by the remote host, or otherwise invalidated,
 the socket will also be closed and should be re-opened before any additional
 calls are made.
 
+=head1 EXAMPLES
+
+=head2 Simple publisher
+
+    use Net::AMQP::RabbitMQ;
+
+    my $channel = 1;
+    my $exchange = "MyExchange.x";  # This exchange must exist already
+    my $routing_key = "foobar";
+
+    my $mq = Net::AMQP::RabbitMQ->new();
+    $mq->connect("localhost", { user => "guest", password => "guest" });
+    $mq->channel_open(1);
+    $mq->publish($channel, $routing_key, "Message Here", { exchange => $exchange });
+    $mq->disconnect();
+
+=head2 Simple consumer
+
+    use Net::AMQP::RabbitMQ;
+    use Data::Dumper;
+
+    my $channel = 1;
+    my $exchange = "MyExchange.x";  # This exchange must exist already
+    my $routing_key = "foobar";
+
+    my $mq = Net::AMQP::RabbitMQ->new();
+    $mq->connect("localhost", { user => "guest", password => "guest" });
+    $mq->channel_open($channel);
+
+    # Declare queue, letting the server auto-generate one and collect the name
+    my $queuename = $mq->queue_declare($channel, "");
+
+    # Bind the new queue to the exchange using the routing key
+    $mq->queue_bind($channel, $queuename, $exchange, $routing_key);
+
+    # Request that messages be sent and receive them until interrupted
+    $mq->consume($channel, $queuename);
+
+    while ( my $message = $mq->recv(0) )
+      {
+        print "Received message:\n";
+        print Dumper($message);
+      }
+
+    $mq->disconnect();
+
 =head1 RUNNING THE TEST SUITE
 
 The test suite runs live tests against a RabbitMQ server at
